

![image](https://img.shields.io/pypi/v/x2embedding.svg) ![image](https://img.shields.io/travis/Jie-Yuan/x2embedding.svg) ![image](https://readthedocs.org/projects/x2embedding/badge/?version=latest)



<h1 align = "center">🔥x2embedding🔥</h1>

---
# Install
```python
pip install -U x2embedding
```

# [Docs](https://jie-yuan.github.io/x2embedding/)

# Usages
```
import x2embedding
```

---
# TODO
